==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d6/df7/saveload__internal_8h.js <==
var saveload__internal_8h =
[
    [ "AfterLoadCompanyStats", "d6/df7/saveload__internal_8h.html#abc852508188d2c574d777351e3f811c7", null ],
    [ "AfterLoadLabelMaps", "d6/df7/saveload__internal_8h.html#afcec95608ba107dc9ee03bc534e786f6", null ],
    [ "AfterLoadLinkGraphs", "d6/df7/saveload__internal_8h.html#a93da9e5898c7a5397dadc13e7fde27da", null ],
    [ "AfterLoadRoadStops", "d6/df7/saveload__internal_8h.html#a9853ef8739f66c1d7896a85e692048f6", null ],
    [ "AfterLoadStations", "d6/df7/saveload__internal_8h.html#ae68a47212f137762b928e9f28ee9574d", null ],
    [ "AfterLoadStoryBook", "d6/df7/saveload__internal_8h.html#af16f7f1c32f35787cbce2588b17a064d", null ],
    [ "AfterLoadVehicles", "d6/df7/saveload__internal_8h.html#ad79cdc104c56cac598ae2b9bb32d7e88", null ],
    [ "ConnectMultiheadedTrains", "d6/df7/saveload__internal_8h.html#a9208ae799abfc5b918fe0cf7b6963812", null ],
    [ "ConvertFromOldCompanyManagerFace", "d6/df7/saveload__internal_8h.html#a6015c51ff17c4ee7f182a1b21e97c242", null ],
    [ "ConvertOldMultiheadToNew", "d6/df7/saveload__internal_8h.html#a78f6dac3a7c129567b52776b6d10f2ab", null ],
    [ "CopyFromOldName", "d6/df7/saveload__internal_8h.html#a5689acc0ff279091fd3c29dc75185260", null ],
    [ "CopyTempEngineData", "d6/df7/saveload__internal_8h.html#af9b0fa90a1485da4b0cf8212befe71d2", null ],
    [ "FixupTrainLengths", "d6/df7/saveload__internal_8h.html#a357cde6fce59f0faefd7a0c6b26166fe", null ],
    [ "GetBaseStationDescription", "d6/df7/saveload__internal_8h.html#a30a72ce827b49dda123d784e8c08c810", null ],
    [ "GetTempDataEngine", "d6/df7/saveload__internal_8h.html#aa445c6ec51c6e7930366735d29df6081", null ],
    [ "InitializeOldNames", "d6/df7/saveload__internal_8h.html#aeec7ca9b3f3d213fa89b782f0d3cb298", null ],
    [ "MoveBuoysToWaypoints", "d6/df7/saveload__internal_8h.html#a3c954f76d8d51c83da36ba7499a74c8c", null ],
    [ "MoveWaypointsToBaseStations", "d6/df7/saveload__internal_8h.html#ac8c5af5a0239427826433004ece3fe9e", null ],
    [ "RemapOldStringID", "d6/df7/saveload__internal_8h.html#a4357f8db5f17b0d0572c8e7d1b53d18e", null ],
    [ "ResetOldNames", "d6/df7/saveload__internal_8h.html#a318bf310d1288020f9c9a69ff4c19932", null ],
    [ "ResetViewportAfterLoadGame", "d6/df7/saveload__internal_8h.html#a1821dff470e3e9ad794ae168014fa83c", null ],
    [ "SaveViewportBeforeSaveGame", "d6/df7/saveload__internal_8h.html#ad3cb5df1ef8c86516d261722259b8828", null ],
    [ "UnpackOldOrder", "d6/df7/saveload__internal_8h.html#a4c5babdcfd1e7069caf12931e93466e9", null ],
    [ "UpdateHousesAndTowns", "d6/df7/saveload__internal_8h.html#ad456c5b194f2a01d539444616f10a58f", null ],
    [ "UpdateOldAircraft", "d6/df7/saveload__internal_8h.html#a658dc5f0b156edc65f1afcecd0ecbe8a", null ],
    [ "_saved_scrollpos_x", "d6/df7/saveload__internal_8h.html#a2a9af09c446d628521e57520d569a9e0", null ],
    [ "_saved_scrollpos_y", "d6/df7/saveload__internal_8h.html#a99f5254bdf889a68d421519c3a3cb91c", null ],
    [ "_saved_scrollpos_zoom", "d6/df7/saveload__internal_8h.html#abd70e636dea40f16768fea02949e8b1d", null ],
    [ "_savegame_type", "d6/df7/saveload__internal_8h.html#ab0504e56d591d788e2c5243fd247c0ec", null ],
    [ "_ttdp_version", "d6/df7/saveload__internal_8h.html#a8d20b8886588be7c56ecbc1d055d391d", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d6/df7/saveload__internal_8h.js <==
var saveload__internal_8h =
[
    [ "AfterLoadCompanyStats", "d6/df7/saveload__internal_8h.html#abc852508188d2c574d777351e3f811c7", null ],
    [ "AfterLoadLabelMaps", "d6/df7/saveload__internal_8h.html#afcec95608ba107dc9ee03bc534e786f6", null ],
    [ "AfterLoadLinkGraphs", "d6/df7/saveload__internal_8h.html#a93da9e5898c7a5397dadc13e7fde27da", null ],
    [ "AfterLoadRoadStops", "d6/df7/saveload__internal_8h.html#a9853ef8739f66c1d7896a85e692048f6", null ],
    [ "AfterLoadStations", "d6/df7/saveload__internal_8h.html#ae68a47212f137762b928e9f28ee9574d", null ],
    [ "AfterLoadStoryBook", "d6/df7/saveload__internal_8h.html#af16f7f1c32f35787cbce2588b17a064d", null ],
    [ "AfterLoadVehicles", "d6/df7/saveload__internal_8h.html#ad79cdc104c56cac598ae2b9bb32d7e88", null ],
    [ "ConnectMultiheadedTrains", "d6/df7/saveload__internal_8h.html#a9208ae799abfc5b918fe0cf7b6963812", null ],
    [ "ConvertFromOldCompanyManagerFace", "d6/df7/saveload__internal_8h.html#a6015c51ff17c4ee7f182a1b21e97c242", null ],
    [ "ConvertOldMultiheadToNew", "d6/df7/saveload__internal_8h.html#a78f6dac3a7c129567b52776b6d10f2ab", null ],
    [ "CopyFromOldName", "d6/df7/saveload__internal_8h.html#aef31f449b208d69dede90f375f6cbba0", null ],
    [ "CopyTempEngineData", "d6/df7/saveload__internal_8h.html#af9b0fa90a1485da4b0cf8212befe71d2", null ],
    [ "FixupTrainLengths", "d6/df7/saveload__internal_8h.html#a357cde6fce59f0faefd7a0c6b26166fe", null ],
    [ "GetBaseStationDescription", "d6/df7/saveload__internal_8h.html#a30a72ce827b49dda123d784e8c08c810", null ],
    [ "GetTempDataEngine", "d6/df7/saveload__internal_8h.html#aa445c6ec51c6e7930366735d29df6081", null ],
    [ "InitializeOldNames", "d6/df7/saveload__internal_8h.html#aeec7ca9b3f3d213fa89b782f0d3cb298", null ],
    [ "MoveBuoysToWaypoints", "d6/df7/saveload__internal_8h.html#a3c954f76d8d51c83da36ba7499a74c8c", null ],
    [ "MoveWaypointsToBaseStations", "d6/df7/saveload__internal_8h.html#ac8c5af5a0239427826433004ece3fe9e", null ],
    [ "RemapOldStringID", "d6/df7/saveload__internal_8h.html#a4357f8db5f17b0d0572c8e7d1b53d18e", null ],
    [ "ResetLabelMaps", "d6/df7/saveload__internal_8h.html#a3e411ba244cbd420c87d8c1a43b4a624", null ],
    [ "ResetOldNames", "d6/df7/saveload__internal_8h.html#a318bf310d1288020f9c9a69ff4c19932", null ],
    [ "ResetOldWaypoints", "d6/df7/saveload__internal_8h.html#a336e80c3fc480c825b376ea681a6a450", null ],
    [ "ResetTempEngineData", "d6/df7/saveload__internal_8h.html#abecdbe229f3b31803b8b7cecfbaed9b5", null ],
    [ "ResetViewportAfterLoadGame", "d6/df7/saveload__internal_8h.html#a1821dff470e3e9ad794ae168014fa83c", null ],
    [ "SaveViewportBeforeSaveGame", "d6/df7/saveload__internal_8h.html#ad3cb5df1ef8c86516d261722259b8828", null ],
    [ "UnpackOldOrder", "d6/df7/saveload__internal_8h.html#a4c5babdcfd1e7069caf12931e93466e9", null ],
    [ "UpdateHousesAndTowns", "d6/df7/saveload__internal_8h.html#ad456c5b194f2a01d539444616f10a58f", null ],
    [ "UpdateOldAircraft", "d6/df7/saveload__internal_8h.html#a658dc5f0b156edc65f1afcecd0ecbe8a", null ],
    [ "_saved_scrollpos_x", "d6/df7/saveload__internal_8h.html#a2a9af09c446d628521e57520d569a9e0", null ],
    [ "_saved_scrollpos_y", "d6/df7/saveload__internal_8h.html#a99f5254bdf889a68d421519c3a3cb91c", null ],
    [ "_saved_scrollpos_zoom", "d6/df7/saveload__internal_8h.html#a61893ee8c2a9f2965f5c39d14362cd23", null ],
    [ "_savegame_type", "d6/df7/saveload__internal_8h.html#ab0504e56d591d788e2c5243fd247c0ec", null ],
    [ "_ttdp_version", "d6/df7/saveload__internal_8h.html#a8d20b8886588be7c56ecbc1d055d391d", null ]
];
